jQuery(document).ready(function($) {
    // ==============================================
    // CONTROLE PRINCIPAL DE UPLOAD
    // ==============================================
    
    let mediaFrame;

    $(document).on('click', '.top-upload-slides', function(e) {
        e.preventDefault();
        const button = $(this);
        const container = button.closest('.top-slides-container');
        const inputs = container.find('input[type="hidden"]');

        // Resetar frame existente
        if (mediaFrame) {
            mediaFrame.off('select');
            mediaFrame.state('library').reset();
        }

        // Novo frame com escopo para o container atual
        mediaFrame = wp.media({
            title: telecom_opcoes_obj.upload_title,
            button: {
                text: telecom_opcoes_obj.upload_button
            },
            library: {
                type: 'image'
            },
            multiple: 'add'
        });

        // Handler específico para o container clicado
        mediaFrame.on('select', function() {
            const attachments = mediaFrame.state().get('selection').toJSON();
            const emptySlots = [];
            
            // 1. Identificar slots vazios apenas no container atual
            inputs.each(function(index) {
                if ($(this).val().trim() === '') {
                    emptySlots.push(index);
                }
            });

            // 2. Preencher apenas os slots do container atual
            attachments.slice(0, emptySlots.length).forEach((attachment, index) => {
                const targetIndex = emptySlots[index];
                const input = inputs.eq(targetIndex);
                const preview = input.siblings('.image-preview');

                if (input.length) {
                    input.val(attachment.url);
                    preview.html(`
                        <img src="${attachment.url}" />
                        <span class="remove-slide">
                            <span class="dashicons dashicons-trash"></span>
                            ${telecom_opcoes_obj.remove_text}
                        </span>
                    `);
                }
            });

            // 3. Forçar atualização do sortable
            container.find('.slides-grid').trigger('sortupdate');
        });

        mediaFrame.open();
    });

    // ==============================================
    // REMOÇÃO DE SLIDES (ESCOPO POR CONTAINER)
    // ==============================================
    
    $(document).on('click', '.remove-slide', function(e) {
        e.preventDefault();
        const slideItem = $(this).closest('.slide-item');
        const container = slideItem.closest('.top-slides-container');

        // Resetar valores apenas no item atual
        slideItem.find('input').val('');
        slideItem.find('.image-preview').html('');

        // Reordenar inputs restantes no mesmo container
        const newOrder = [];
        container.find('.slide-item input').each(function() {
            newOrder.push($(this).val());
        });
        
        container.find('input[type="hidden"]').each(function(index) {
            $(this).val(newOrder[index] || '');
        });
    });

    // ==============================================
    // REORDENAÇÃO COM ESCOPO POR CONTAINER
    // ==============================================
    
    $('.slides-grid').sortable({
        items: '.slide-item',
        placeholder: 'slide-placeholder',
        cursor: 'move',
        opacity: 0.7,
        connectWith: '.slides-grid',
        tolerance: 'pointer',
        start: function(e, ui) {
            ui.placeholder.height(ui.item.outerHeight());
        },
        update: function(e, ui) {
            const container = ui.item.closest('.top-slides-container');
            const newOrder = [];
            
            // Atualizar apenas o container afetado
            container.find('.slide-item input').each(function() {
                newOrder.push($(this).val());
            });

            container.find('input[type="hidden"]').each(function(index) {
                $(this).val(newOrder[index] || '');
            });
        }
    });

    // ==============================================
    // GESTÃO DE ESTADO
    // ==============================================
    
    $(window).on('beforeunload', function() {
        if (mediaFrame) {
            mediaFrame.off('select close');
            mediaFrame = null;
        }
    });
});