jQuery(document).ready(function($) {
    // ==============================================
    // UPLOAD DE IMAGEM ÚNICA PARA TECNOLOGIA
    // ==============================================
    
    $(document).on('click', '.top-plan-metabox .top-upload-slides', function(e) {
        e.preventDefault();
        const button = $(this);
        const container = button.closest('.top-slides-container');
        const input = container.find('input[type="hidden"]');
        const preview = container.find('.image-preview');
        
        const custom_uploader = wp.media({
            title: telecom_opcoes_obj.upload_title,
            button: {
                text: telecom_opcoes_obj.upload_button
            },
            multiple: false,
            library: {
                type: 'image'
            }
        });

        // Pré-selecionar imagem existente
        custom_uploader.on('open', function() {
            if(input.val()) {
                const selection = custom_uploader.state().get('selection');
                const attachment = wp.media.attachment(input.val());
                attachment.fetch();
                selection.add(attachment);
            }
        });

        custom_uploader.on('select', function() {
            const attachment = custom_uploader.state().get('selection').first().toJSON();
            
            // Atualizar input e preview
            input.val(attachment.url);
            preview.html(`
                <img src="${attachment.url}" style="max-width:100%; height:auto; object-fit:contain;" />
                <span class="remove-slide">
                    <span class="dashicons dashicons-trash"></span>
                    ${telecom_opcoes_obj.remove_text}
                </span>
            `);
            
            // Esconder botão de upload
            button.hide();
            
            // Forçar redesenho do preview
            preview.hide().show(0);
        }).open();
    });

    // ==============================================
    // REMOÇÃO DE IMAGEM DA TECNOLOGIA
    // ==============================================
    
    $(document).on('click', '.top-plan-metabox .remove-slide', function(e) {
        e.preventDefault();
        const container = $(this).closest('.top-slides-container');
        
        // Resetar valores
        container.find('input').val('');
        container.find('.image-preview').html('');
        
        // Mostrar botão de upload novamente
        container.find('.top-upload-slides').show();
        
        // Adicionar feedback visual
        container.find('.image-preview').css({
            'background': '#f8d7da',
            'border': '2px dashed #dc3545'
        }).animate({
            backgroundColor: '#f8f9fa',
            borderColor: '#c3c4c7'
        }, 1000);
    });

    // ==============================================
    // VALIDAÇÃO DE TAMANHO DA IMAGEM
    // ==============================================
    
    $(document).on('mouseenter', '.top-plan-metabox .image-preview img', function() {
        const img = new Image();
        img.src = $(this).attr('src');
        
        img.onload = function() {
            const container = $(this).closest('.top-slides-container');
            const recommended = container.find('.description').text().match(/\d+/g);
            
            if(recommended && recommended.length >= 2) {
                const minWidth = parseInt(recommended[0]);
                const minHeight = parseInt(recommended[1]);
                
                if(img.naturalWidth < minWidth || img.naturalHeight < minHeight) {
                    $(this).css('border', '2px solid #dc3545');
                    container.append(`
                        <div class="notice notice-error inline" style="margin-top:10px;">
                            <p>${telecom_opcoes_obj.size_warning}</p>
                        </div>
                    `);
                    
                    // Remover aviso após 5 segundos
                    setTimeout(() => {
                        container.find('.notice-error').fadeOut(500, function() {
                            $(this).remove();
                        });
                    }, 5000);
                }
            }
        }.bind(this);
    });

    // ==============================================
    // AJUSTES DE LAYOUT DINÂMICOS
    // ==============================================
    
    // Ajustar altura do preview
    function adjustPreviewHeight() {
        $('.top-plan-metabox .image-preview').each(function() {
            const width = $(this).width();
            $(this).css('height', width * 0.5625 + 'px'); // Proporção 16:9
        });
    }
    
    // Executar no carregamento e redimensionamento
    $(window).on('load resize', adjustPreviewHeight);
    setTimeout(adjustPreviewHeight, 300); // Delay para elementos dinâmicos
    
    // ==============================================
    // INICIALIZAR TOOLTIPS
    // ==============================================
    
    $(document).tooltip({
        items: '[data-tooltip]',
        content: function() {
            return $(this).attr('data-tooltip');
        },
        position: {
            my: "center bottom-20",
            at: "center top"
        },
        show: {
            duration: 200
        },
        hide: {
            duration: 100
        }
    });
});