<?php
if (!defined('ABSPATH')) {
    exit;
}

// Verificar se o Elementor está carregado corretamente
if (!class_exists('Elementor\Core\DynamicTags\Tag')) {
    return;
}

use Elementor\Controls_Manager;
use Elementor\Core\DynamicTags\Tag;
use Elementor\Plugin;

// ==============================================
// TAGS DINÂMICAS DO ELEMENTOR PARA INFORMAÇÕES DO PROVEDOR
// ==============================================

class TOP_Elementor_Provider_Info_Tags extends Tag {

    public function get_name() {
        return 'top_provider_info';
    }

    public function get_title() {
        return __('Informações do Provedor', 'telecom-opcoes-e-planos');
    }

    public function get_group() {
        return 'site';
    }

    public function get_categories() {
        return [
            \Elementor\Modules\DynamicTags\Module::TEXT_CATEGORY,
            \Elementor\Modules\DynamicTags\Module::URL_CATEGORY,
        ];
    }

    protected function register_controls() {
        $this->add_control(
            'field',
            [
                'label' => __('Campo', 'telecom-opcoes-e-planos'),
                'type' => Controls_Manager::SELECT,
                'default' => 'company_name',
                'options' => [
                    'company_name'       => __('Nome da Empresa', 'telecom-opcoes-e-planos'),
                    'company_cnpj'       => __('CNPJ', 'telecom-opcoes-e-planos'),
                    'company_phone1'     => __('Telefone 1', 'telecom-opcoes-e-planos'),
                    'company_phone2'     => __('Telefone 2', 'telecom-opcoes-e-planos'),
                    'company_email'      => __('Email', 'telecom-opcoes-e-planos'),
                    'company_whatsapp'   => __('WhatsApp', 'telecom-opcoes-e-planos'),
                    'subscriber_center'  => __('Central do Assinante', 'telecom-opcoes-e-planos'),
                    'company_instagram'  => __('Instagram', 'telecom-opcoes-e-planos'),
                    'company_facebook'   => __('Facebook', 'telecom-opcoes-e-planos'),
                    'company_sobre_titulo' => __('Título Sobre Nós', 'telecom-opcoes-e-planos'),
                    'company_cobertura'  => __('Áreas de Cobertura', 'telecom-opcoes-e-planos'),
                ],
            ]
        );
    }

    public function render() {
        $field = $this->get_settings('field');
        $value = get_option($field);

        // Sanitizar saída
        if (in_array($field, ['subscriber_center', 'company_email', 'company_whatsapp', 'company_instagram', 'company_facebook'])) {
            echo esc_url($value);
        } else {
            echo wp_kses_post($value);
        }
    }
}

// ==============================================
// REGISTRAR TAGS NO ELEMENTOR
// ==============================================

function top_register_custom_elementor_tags($dynamic_tags) {
    // Verificar se o Elementor está carregado
    if (class_exists('Elementor\Core\DynamicTags\Tag')) {
        $dynamic_tags->register(new TOP_Elementor_Provider_Info_Tags());
    }
}

// Registrar tags apenas se o Elementor estiver ativo
add_action('elementor/dynamic_tags/register', function($dynamic_tags) {
    if (class_exists('TOP_Elementor_Provider_Info_Tags')) {
        $dynamic_tags->register(new TOP_Elementor_Provider_Info_Tags());
    }
});