<?php
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// ==============================================
// REGISTRO DO MENU E SUBMENUS
// ==============================================

function top_register_custom_options_page() {
    add_menu_page(
        esc_html__('Provedor', 'telecom-opcoes-e-planos'),
        esc_html__('Provedor', 'telecom-opcoes-e-planos'),
        'manage_options',
        'company-settings',
        'top_display_empresa_page',
        'dashicons-admin-generic',
        20
    );

    add_submenu_page(
        'company-settings',
        esc_html__('Empresa', 'telecom-opcoes-e-planos'),
        esc_html__('Empresa', 'telecom-opcoes-e-planos'),
        'manage_options',
        'company-settings',
        'top_display_empresa_page'
    );

    add_submenu_page(
        'company-settings',
        esc_html__('Contatos', 'telecom-opcoes-e-planos'),
        esc_html__('Contatos', 'telecom-opcoes-e-planos'),
        'manage_options',
        'contatos-settings',
        'top_display_contatos_page'
    );

    add_submenu_page(
        'company-settings',
        esc_html__('Slides', 'telecom-opcoes-e-planos'),
        esc_html__('Slides', 'telecom-opcoes-e-planos'),
        'manage_options',
        'slides-settings',
        'top_display_slides_page'
    );
}

add_action('admin_menu', 'top_register_custom_options_page');

// ==============================================
// PÁGINA EMPRESA
// ==============================================

function top_display_empresa_page() {
    if (!current_user_can('manage_options')) return;
    ?>
    <div class="wrap">
        <h1><?php esc_html_e('Configurações da Empresa', 'telecom-opcoes-e-planos'); ?></h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('top_empresa_settings_group');
            do_settings_sections('empresa-settings');
            submit_button(esc_html__('Salvar Configurações', 'telecom-opcoes-e-planos'));
            ?>
        </form>
    </div>
    <?php
}

function top_setup_empresa_settings() {
    register_setting('top_empresa_settings_group', 'company_name', 'sanitize_text_field');
    register_setting('top_empresa_settings_group', 'company_cnpj', 'sanitize_text_field');
    register_setting('top_empresa_settings_group', 'company_sobre_titulo', 'sanitize_text_field');
    register_setting('top_empresa_settings_group', 'company_sobre_texto', 'sanitize_textarea_field');
    register_setting('top_empresa_settings_group', 'company_cobertura', 'sanitize_textarea_field');
    register_setting('top_empresa_settings_group', 'company_endereco', 'sanitize_textarea_field');

    add_settings_section(
        'top_empresa_section',
        esc_html__('Informações Gerais', 'telecom-opcoes-e-planos'),
        null,
        'empresa-settings'
    );

    add_settings_field(
        'company_name',
        esc_html__('Nome da Empresa', 'telecom-opcoes-e-planos'),
        'top_display_company_name_field',
        'empresa-settings',
        'top_empresa_section'
    );

    add_settings_field(
        'company_cnpj',
        esc_html__('CNPJ', 'telecom-opcoes-e-planos'),
        'top_display_company_cnpj_field',
        'empresa-settings',
        'top_empresa_section'
    );

    add_settings_field(
        'company_sobre_titulo',
        esc_html__('Título Sobre Nós', 'telecom-opcoes-e-planos'),
        'top_display_sobre_titulo_field',
        'empresa-settings',
        'top_empresa_section'
    );

    add_settings_field(
        'company_sobre_texto',
        esc_html__('Texto Sobre Nós', 'telecom-opcoes-e-planos'),
        'top_display_sobre_texto_field',
        'empresa-settings',
        'top_empresa_section'
    );

    add_settings_field(
        'company_cobertura',
        esc_html__('Áreas de Cobertura', 'telecom-opcoes-e-planos'),
        'top_display_cobertura_field',
        'empresa-settings',
        'top_empresa_section'
    );

    add_settings_field(
        'company_endereco',
        esc_html__('Endereço', 'telecom-opcoes-e-planos'),
        'top_display_endereco_field',
        'empresa-settings',
        'top_empresa_section'
    );
}

// ==============================================
// PÁGINA CONTATOS
// ==============================================

function top_display_contatos_page() {
    if (!current_user_can('manage_options')) return;
    ?>
    <div class="wrap">
        <h1><?php esc_html_e('Configurações de Contatos', 'telecom-opcoes-e-planos'); ?></h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('top_contatos_settings_group');
            do_settings_sections('contatos-settings');
            submit_button(esc_html__('Salvar Configurações', 'telecom-opcoes-e-planos'));
            ?>
        </form>
    </div>
    <?php
}

function top_setup_contatos_settings() {
    register_setting('top_contatos_settings_group', 'company_phone1', 'sanitize_text_field');
    register_setting('top_contatos_settings_group', 'company_phone2', 'sanitize_text_field');
    register_setting('top_contatos_settings_group', 'company_email', 'sanitize_email');
    register_setting('top_contatos_settings_group', 'company_whatsapp', 'sanitize_text_field');
    register_setting('top_contatos_settings_group', 'company_instagram', 'esc_url_raw');
    register_setting('top_contatos_settings_group', 'company_facebook', 'esc_url_raw');

    add_settings_section(
        'top_contatos_section',
        esc_html__('Detalhes de Contato', 'telecom-opcoes-e-planos'),
        null,
        'contatos-settings'
    );

    add_settings_field(
        'company_phone1',
        esc_html__('Telefone 1', 'telecom-opcoes-e-planos'),
        'top_display_phone1_field',
        'contatos-settings',
        'top_contatos_section'
    );

    add_settings_field(
        'company_phone2',
        esc_html__('Telefone 2', 'telecom-opcoes-e-planos'),
        'top_display_phone2_field',
        'contatos-settings',
        'top_contatos_section'
    );

    add_settings_field(
        'company_email',
        esc_html__('Email', 'telecom-opcoes-e-planos'),
        'top_display_email_field',
        'contatos-settings',
        'top_contatos_section'
    );

    add_settings_field(
        'company_whatsapp',
        esc_html__('WhatsApp', 'telecom-opcoes-e-planos'),
        'top_display_whatsapp_field',
        'contatos-settings',
        'top_contatos_section'
    );

    add_settings_field(
        'company_instagram',
        esc_html__('Instagram', 'telecom-opcoes-e-planos'),
        'top_display_instagram_field',
        'contatos-settings',
        'top_contatos_section'
    );

    add_settings_field(
        'company_facebook',
        esc_html__('Facebook', 'telecom-opcoes-e-planos'),
        'top_display_facebook_field',
        'contatos-settings',
        'top_contatos_section'
    );
}

// ==============================================
// PÁGINA SLIDES (PARTE MODIFICADA)
// ==============================================

function top_display_slides_page() {
    if (!current_user_can('manage_options')) return;
    
    wp_enqueue_media();
    
    // 1. Enfileirar script JS
    wp_enqueue_script(
        'top-slides-js',
        plugins_url('assets/js/admin-slides.js', dirname(__FILE__)),
        array('jquery', 'jquery-ui-sortable', 'media-views'),
        '1.0.4',
        true
    );

    // 2. Localizar textos para o JavaScript (CORREÇÃO ADICIONADA)
    wp_localize_script('top-slides-js', 'telecom_opcoes_obj', array(
        'upload_title'   => esc_html__('Selecione Imagens', 'telecom-opcoes-e-planos'),
        'upload_button'  => esc_html__('Usar estas Imagens', 'telecom-opcoes-e-planos'),
        'remove_text'    => esc_html__('Remover', 'telecom-opcoes-e-planos')
    ));

    // 3. Enfileirar CSS
    wp_enqueue_style(
        'top-slides-css',
        plugins_url('assets/css/admin-slides.css', dirname(__FILE__)),
        array(),
        '1.0.4'
    );
    ?>
    <div class="wrap">
        <h1><?php esc_html_e('Gerenciar Slides', 'telecom-opcoes-e-planos'); ?></h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('top_slides_settings_group');
            do_settings_sections('slides-settings');
            submit_button(esc_html__('Salvar Slides', 'telecom-opcoes-e-planos'));
            ?>
        </form>
    </div>
    <?php
}

function top_setup_slides_settings() {
    register_setting('top_slides_settings_group', 'top_slides_desktop', 'top_sanitize_slides');
    register_setting('top_slides_settings_group', 'top_slides_mobile', 'top_sanitize_slides');

    add_settings_section(
        'top_slides_section',
        esc_html__('Configurações dos Slides', 'telecom-opcoes-e-planos'),
        null,
        'slides-settings'
    );

    add_settings_field(
        'slides_desktop',
        esc_html__('Slides Desktop (Máx. 4)', 'telecom-opcoes-e-planos'),
        'top_display_slides_desktop_field',
        'slides-settings',
        'top_slides_section'
    );

    add_settings_field(
        'slides_mobile',
        esc_html__('Slides Mobile (Máx. 4)', 'telecom-opcoes-e-planos'),
        'top_display_slides_mobile_field',
        'slides-settings',
        'top_slides_section'
    );
}

// ==============================================
// FUNÇÕES DE EXIBIÇÃO DE CAMPOS
// ==============================================

// ----- EMPRESA -----
function top_display_company_name_field() {
    $value = get_option('company_name');
    echo '<input type="text" name="company_name" value="' . esc_attr($value) . '" class="regular-text">';
}

function top_display_company_cnpj_field() {
    $value = get_option('company_cnpj');
    echo '<input type="text" name="company_cnpj" value="' . esc_attr($value) . '" class="regular-text">';
}

function top_display_sobre_titulo_field() {
    $value = get_option('company_sobre_titulo');
    echo '<input type="text" name="company_sobre_titulo" value="' . esc_attr($value) . '" class="regular-text">';
}

function top_display_sobre_texto_field() {
    $value = get_option('company_sobre_texto');
    echo '<textarea name="company_sobre_texto" rows="5" class="large-text">' . esc_textarea($value) . '</textarea>';
}

function top_display_cobertura_field() {
    $value = get_option('company_cobertura');
    echo '<textarea name="company_cobertura" rows="5" class="large-text">' . esc_textarea($value) . '</textarea>';
}

function top_display_endereco_field() {
    $value = get_option('company_endereco');
    echo '<textarea name="company_endereco" rows="3" class="large-text">' . esc_textarea($value) . '</textarea>';
}

// ----- CONTATOS -----
function top_display_phone1_field() {
    $value = get_option('company_phone1');
    echo '<input type="text" name="company_phone1" value="' . esc_attr($value) . '" class="regular-text">';
}

function top_display_phone2_field() {
    $value = get_option('company_phone2');
    echo '<input type="text" name="company_phone2" value="' . esc_attr($value) . '" class="regular-text">';
}

function top_display_email_field() {
    $value = get_option('company_email');
    echo '<input type="email" name="company_email" value="' . esc_attr($value) . '" class="regular-text">';
}

function top_display_whatsapp_field() {
    $value = get_option('company_whatsapp');
    echo '<input type="text" name="company_whatsapp" value="' . esc_attr($value) . '" class="regular-text">';
}

function top_display_instagram_field() {
    $value = get_option('company_instagram');
    echo '<input type="url" name="company_instagram" value="' . esc_url($value) . '" class="regular-text" placeholder="https://instagram.com/...">';
}

function top_display_facebook_field() {
    $value = get_option('company_facebook');
    echo '<input type="url" name="company_facebook" value="' . esc_url($value) . '" class="regular-text" placeholder="https://facebook.com/...">';
}

// ----- SLIDES -----
function top_sanitize_slides($input) {
    $sanitized = array();
    if (is_array($input)) {
        foreach ($input as $url) {
            $clean_url = esc_url_raw(wp_unslash($url));
            if (!empty($clean_url)) $sanitized[] = $clean_url;
        }
        return array_slice($sanitized, 0, 4);
    }
    return array();
}

function top_display_slides_desktop_field() {
    $slides = get_option('top_slides_desktop', array());
    ?>
    <div class="top-slides-container">
        <div class="slides-grid">
            <?php for ($i = 0; $i < 4; $i++) : 
                $url = $slides[$i] ?? '';
            ?>
                <div class="slide-item">
                    <div class="image-preview">
                        <?php if ($url) : ?>
                            <img src="<?php echo esc_url($url); ?>" />
                            <span class="remove-slide">
                                <span class="dashicons dashicons-trash"></span>
                                <?php esc_html_e('Remover', 'telecom-opcoes-e-planos'); ?>
                            </span>
                        <?php endif; ?>
                    </div>
                    <input type="hidden" name="top_slides_desktop[]" value="<?php echo esc_attr($url); ?>">
                </div>
            <?php endfor; ?>
        </div>
        <button type="button" class="button top-upload-slides"><?php esc_html_e('Selecionar Slides Desktop', 'telecom-opcoes-e-planos'); ?></button>
        <p class="description"><?php esc_html_e('Tamanho recomendado: 1920x600 pixels', 'telecom-opcoes-e-planos'); ?></p>
    </div>
    <?php
}

function top_display_slides_mobile_field() {
    $slides = get_option('top_slides_mobile', array());
    ?>
    <div class="top-slides-container">
        <div class="slides-grid">
            <?php for ($i = 0; $i < 4; $i++) : 
                $url = $slides[$i] ?? '';
            ?>
                <div class="slide-item">
                    <div class="image-preview">
                        <?php if ($url) : ?>
                            <img src="<?php echo esc_url($url); ?>" />
                            <span class="remove-slide">
                                <span class="dashicons dashicons-trash"></span>
                                <?php esc_html_e('Remover', 'telecom-opcoes-e-planos'); ?>
                            </span>
                        <?php endif; ?>
                    </div>
                    <input type="hidden" name="top_slides_mobile[]" value="<?php echo esc_attr($url); ?>">
                </div>
            <?php endfor; ?>
        </div>
        <button type="button" class="button top-upload-slides"><?php esc_html_e('Selecionar Slides Mobile', 'telecom-opcoes-e-planos'); ?></button>
        <p class="description"><?php esc_html_e('Tamanho recomendado: 1080x1350 pixels', 'telecom-opcoes-e-planos'); ?></p>
    </div>
    <?php
}

// ==============================================
// INICIALIZAÇÃO
// ==============================================

add_action('admin_init', function() {
    top_setup_empresa_settings();
    top_setup_contatos_settings();
    top_setup_slides_settings();
});