<?php
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// ==============================================
// REGISTRAR TIPO DE POST PARA PLANOS
// ==============================================

function top_register_plan_post_type() {
    $labels = array(
        'name'                  => esc_html_x('Planos', 'Post Type General Name', 'telecom-opcoes-e-planos'),
        'singular_name'         => esc_html_x('Plano', 'Post Type Singular Name', 'telecom-opcoes-e-planos'),
        'menu_name'             => esc_html__('Planos', 'telecom-opcoes-e-planos'),
        'name_admin_bar'        => esc_html__('Plano', 'telecom-opcoes-e-planos'),
        'add_new'               => esc_html__('Adicionar Novo', 'telecom-opcoes-e-planos'),
        'add_new_item'          => esc_html__('Adicionar Novo Plano', 'telecom-opcoes-e-planos'),
        'new_item'              => esc_html__('Novo Plano', 'telecom-opcoes-e-planos'),
        'edit_item'             => esc_html__('Editar Plano', 'telecom-opcoes-e-planos'),
        'view_item'             => esc_html__('Ver Plano', 'telecom-opcoes-e-planos'),
        'all_items'             => esc_html__('Todos os Planos', 'telecom-opcoes-e-planos'),
        'search_items'          => esc_html__('Buscar Planos', 'telecom-opcoes-e-planos'),
        'not_found'             => esc_html__('Nenhum plano encontrado.', 'telecom-opcoes-e-planos'),
        'not_found_in_trash'    => esc_html__('Nenhum plano na lixeira.', 'telecom-opcoes-e-planos'),
        'featured_image'        => esc_html__('Imagem Destaque', 'telecom-opcoes-e-planos'),
        'set_featured_image'    => esc_html__('Definir imagem destaque', 'telecom-opcoes-e-planos'),
        'remove_featured_image' => esc_html__('Remover imagem destaque', 'telecom-opcoes-e-planos'),
        'use_featured_image'    => esc_html__('Usar como imagem destaque', 'telecom-opcoes-e-planos'),
    );

    $args = array(
        'labels'             => $labels,
        'public'             => true,
        'publicly_queryable' => true,
        'show_ui'            => true,
        'show_in_menu'       => true,
        'query_var'          => true,
        'rewrite'            => array('slug' => 'plan'),
        'capability_type'    => 'post',
        'has_archive'        => true,
        'hierarchical'       => false,
        'menu_position'      => null,
        'menu_icon'          => 'dashicons-admin-site',
        'supports'           => array('title'),
        'show_in_rest'       => true,
    );

    register_post_type('top_plan', $args);
}

add_action('init', 'top_register_plan_post_type');

// ==============================================
// METABOXES PARA DETALHES DO PLANO
// ==============================================

function top_add_plan_metaboxes() {
    add_meta_box(
        'top_plan_details',
        esc_html__('Detalhes do Plano', 'telecom-opcoes-e-planos'),
        'top_display_plan_metaboxes',
        'top_plan',
        'normal',
        'high'
    );
}

add_action('add_meta_boxes', 'top_add_plan_metaboxes');

// ==============================================
// EXIBIR CAMPOS DO METABOX (LAYOUT ATUALIZADO)
// ==============================================

function top_display_plan_metaboxes($post) {
    // Recuperar valores com segurança
    $velocidade = get_post_meta($post->ID, '_top_plan_velocidade', true);
    $preco = get_post_meta($post->ID, '_top_plan_preco', true);
    $tecnologia = get_post_meta($post->ID, '_top_plan_tecnologia', true);
    $tecnologia_imagem = get_post_meta($post->ID, '_top_plan_tecnologia_imagem', true);
    $diferencial1 = get_post_meta($post->ID, '_top_plan_diferencial1', true);
    $diferencial2 = get_post_meta($post->ID, '_top_plan_diferencial2', true);
    $diferencial3 = get_post_meta($post->ID, '_top_plan_diferencial3', true);
    $destaque = get_post_meta($post->ID, '_top_plan_destaque', true);

    // Nonce para verificação
    wp_nonce_field('top_save_plan_details', 'top_plan_details_nonce');

    // Campos
    ?>
    <div class="top-plan-metabox">
        <!-- Velocidade -->
        <div class="top-field-group">
            <label for="top_plan_velocidade"><?php esc_html_e('Velocidade:', 'telecom-opcoes-e-planos'); ?></label>
            <input type="text" id="top_plan_velocidade" name="_top_plan_velocidade" 
                   value="<?php echo esc_attr($velocidade); ?>" class="widefat">
            <p class="description"><?php esc_html_e('Exemplo: 100 Mbps', 'telecom-opcoes-e-planos'); ?></p>
        </div>

        <!-- Preço -->
        <div class="top-field-group">
            <label for="top_plan_preco"><?php esc_html_e('Preço:', 'telecom-opcoes-e-planos'); ?></label>
            <input type="text" id="top_plan_preco" name="_top_plan_preco" 
                   value="<?php echo esc_attr($preco); ?>" class="widefat">
            <p class="description"><?php esc_html_e('Formato: R$ 99,90', 'telecom-opcoes-e-planos'); ?></p>
        </div>

        <!-- Tecnologia -->
        <div class="top-field-group">
            <label for="top_plan_tecnologia"><?php esc_html_e('Tecnologia:', 'telecom-opcoes-e-planos'); ?></label>
            <input type="text" id="top_plan_tecnologia" name="_top_plan_tecnologia" 
                   value="<?php echo esc_attr($tecnologia); ?>" class="widefat">
            <p class="description"><?php esc_html_e('Exemplo: Fibra Óptica', 'telecom-opcoes-e-planos'); ?></p>
        </div>

        <!-- Imagem da Tecnologia -->
        <div class="top-field-group">
            <label><?php esc_html_e('Imagem da Tecnologia:', 'telecom-opcoes-e-planos'); ?></label>
            <div class="top-slides-container">
                <div class="slides-grid">
                    <div class="slide-item">
                        <div class="image-preview">
                            <?php if ($tecnologia_imagem) : ?>
                                <img src="<?php echo esc_url($tecnologia_imagem); ?>" 
                                     style="object-fit: contain; width: 100%; height: 100%;" />
                                <span class="remove-slide">
                                    <span class="dashicons dashicons-trash"></span>
                                    <?php esc_html_e('Remover', 'telecom-opcoes-e-planos'); ?>
                                </span>
                            <?php endif; ?>
                        </div>
                        <input type="hidden" 
                               name="_top_plan_tecnologia_imagem" 
                               value="<?php echo esc_url($tecnologia_imagem); ?>">
                    </div>
                </div>
                <button type="button" 
                        class="button top-upload-slides" 
                        <?php echo $tecnologia_imagem ? 'style="display:none;"' : ''; ?>>
                    <?php esc_html_e('Selecionar Imagem', 'telecom-opcoes-e-planos'); ?>
                </button>
                <p class="description">
                    <?php esc_html_e('Tamanho recomendado: 600x600 pixels (Formatos: PNG, SVG)', 'telecom-opcoes-e-planos'); ?>
                </p>
            </div>
        </div>

        <!-- Diferenciais -->
        <div class="top-field-group">
            <label><?php esc_html_e('Diferenciais:', 'telecom-opcoes-e-planos'); ?></label>
            <input type="text" 
                   name="_top_plan_diferencial1" 
                   value="<?php echo esc_attr($diferencial1); ?>" 
                   placeholder="<?php esc_attr_e('Diferencial 1', 'telecom-opcoes-e-planos'); ?>" 
                   class="widefat">
            <input type="text" 
                   name="_top_plan_diferencial2" 
                   value="<?php echo esc_attr($diferencial2); ?>" 
                   placeholder="<?php esc_attr_e('Diferencial 2', 'telecom-opcoes-e-planos'); ?>" 
                   class="widefat">
            <input type="text" 
                   name="_top_plan_diferencial3" 
                   value="<?php echo esc_attr($diferencial3); ?>" 
                   placeholder="<?php esc_attr_e('Diferencial 3', 'telecom-opcoes-e-planos'); ?>" 
                   class="widefat">
        </div>

        <!-- Destaque -->
        <div class="top-field-group">
            <label>
                <input type="checkbox" 
                       name="_top_plan_destaque" 
                       value="1" 
                       <?php checked($destaque, '1'); ?>>
                <?php esc_html_e('Marcar como plano destaque', 'telecom-opcoes-e-planos'); ?>
            </label>
            <p class="description"><?php esc_html_e('Este plano será destacado nas listagens', 'telecom-opcoes-e-planos'); ?></p>
        </div>
    </div>
    <?php
}

// ==============================================
// SALVAR DADOS DO METABOX (SEGURANÇA REFORÇADA)
// ==============================================

function top_save_plan_details($post_id) {
    // 1. Verificação de segurança - nonce, autosave, permissões
    if (!isset($_POST['top_plan_details_nonce'])) {
        return;
    }

    if (!wp_verify_nonce(sanitize_key($_POST['top_plan_details_nonce']), 'top_save_plan_details')) {
        return;
    }

    if (!current_user_can('edit_post', $post_id)) {
        return;
    }

    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }

    // 2. Mapeamento de campos com sanitização
    $fields = [
        '_top_plan_velocidade' => [
            'sanitize' => 'sanitize_text_field',
            'default' => ''
        ],
        '_top_plan_preco' => [
            'sanitize' => function($value) {
                $clean = sanitize_text_field($value);
                return str_replace(',', '.', $clean);
            },
            'default' => ''
        ],
        '_top_plan_tecnologia' => [
            'sanitize' => 'sanitize_text_field',
            'default' => ''
        ],
        '_top_plan_tecnologia_imagem' => [
            'sanitize' => 'esc_url_raw',
            'default' => ''
        ],
        '_top_plan_diferencial1' => [
            'sanitize' => 'sanitize_text_field',
            'default' => ''
        ],
        '_top_plan_diferencial2' => [
            'sanitize' => 'sanitize_text_field',
            'default' => ''
        ],
        '_top_plan_diferencial3' => [
            'sanitize' => 'sanitize_text_field',
            'default' => ''
        ],
        '_top_plan_destaque' => [
            'sanitize' => function($value) {
                // Não acesse $_POST diretamente aqui, use o valor passado
                return !empty($value) ? '1' : '0';
            },
            'default' => '0'
        ]
    ];

    // 3. Processar cada campo
    foreach ($fields as $field => $config) {
        // Para o campo checkbox, trate separadamente
        if ($field === '_top_plan_destaque') {
            $clean_value = isset($_POST[$field]) ? '1' : '0';
            update_post_meta($post_id, $field, $clean_value);
            continue;
        }
        
        // Para os demais campos
        if (!isset($_POST[$field])) {
            continue;
        }

        // Obtenha o valor e sanitize-o
        $raw_value = sanitize_text_field(wp_unslash($_POST[$field]));
        
        // Sanitização adicional conforme definido
        if (!empty($raw_value)) {
            $clean_value = is_callable($config['sanitize']) 
                ? call_user_func($config['sanitize'], $raw_value)
                : $raw_value; // Já está sanitizado pelo sanitize_text_field acima
        } else {
            $clean_value = $config['default'];
        }

        update_post_meta($post_id, $field, $clean_value);
    }
}

add_action('save_post', 'top_save_plan_details');

// ==============================================
// SCRIPTS E ESTILOS ADMIN
// ==============================================

function top_enqueue_plan_admin_scripts() {
    global $post_type;
    
    if ($post_type === 'top_plan') {
        wp_enqueue_media();
        
        // Script principal
        wp_enqueue_script(
            'top-plan-admin-js',
            plugins_url('assets/js/admin.js', dirname(__FILE__)),
            array('jquery', 'jquery-ui-sortable'),
            filemtime(plugin_dir_path(dirname(__FILE__)) . 'assets/js/admin.js'),
            true
        );

        // Estilos compartilhados
        wp_enqueue_style(
            'top-admin-styles',
            plugins_url('assets/css/admin-slides.css', dirname(__FILE__)),
            array(),
            filemtime(plugin_dir_path(dirname(__FILE__)) . 'assets/css/admin-slides.css')
        );

        // Localizar textos
        wp_localize_script('top-plan-admin-js', 'telecom_opcoes_obj', [
            'upload_title'   => esc_html__('Selecione uma Imagem', 'telecom-opcoes-e-planos'),
            'upload_button'  => esc_html__('Usar esta Imagem', 'telecom-opcoes-e-planos'),
            'remove_text'    => esc_html__('Remover', 'telecom-opcoes-e-planos'),
            'size_warning'   => esc_html__('A imagem está abaixo do tamanho recomendado!', 'telecom-opcoes-e-planos')
        ]);
    }
}

add_action('admin_enqueue_scripts', 'top_enqueue_plan_admin_scripts');