<?php
/**
 * Plugin Name: Telecom Opções e Planos
 * Plugin URI: https://www.saivercon.com/
 * Description: Plugin para gerenciar informações de provedores de telecomunicações e seus planos.
 * Version: 1.0.4
 * Requires at least: 6.0
 * Requires PHP: 7.4
 * Author: Saivercon Tecnologia
 * Author URI: https://www.saivercon.com/
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: telecom-opcoes-e-planos
 * Domain Path: /languages
 */

// Prevenir acesso direto
if (!defined('ABSPATH')) {
    exit; 
}

// Carregar traduções
add_action('plugins_loaded', 'top_load_textdomain');
function top_load_textdomain() {
    load_plugin_textdomain(
        'telecom-opcoes-e-planos',
        false,
        dirname(plugin_basename(__FILE__)) . '/languages/'
    );
}

// Incluir arquivos necessários
require_once plugin_dir_path(__FILE__) . 'includes/top-options-page.php';     // Configurações do provedor
require_once plugin_dir_path(__FILE__) . 'includes/top-plan-post-type.php';   // Tipo de post para planos

// Carregar integração com Elementor somente se estiver ativo
add_action('plugins_loaded', function() {
    if (did_action('elementor/loaded')) {
        require_once plugin_dir_path(__FILE__) . 'includes/top-elementor-integration.php';
    }
});

// Adicionar link de configurações na página de plugins
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'top_add_settings_link');
function top_add_settings_link($links) {
    $settings_link = '<a href="admin.php?page=company-settings">' . esc_html__('Configurações', 'telecom-opcoes-e-planos') . '</a>';
    array_unshift($links, $settings_link);
    return $links;
}

// Adicionar aviso de versão Grátis
add_action('admin_notices', 'top_admin_notice');
function top_admin_notice() {
    $screen = get_current_screen();
    
    if ($screen->id === 'toplevel_page_company-settings' || $screen->post_type === 'top_plan') {
        echo '<div class="notice notice-info is-dismissible">';
        echo '<p><strong>' . esc_html__('Atenção:', 'telecom-opcoes-e-planos') . '</strong> ';
        printf(
            /* translators: %s: Link para o site da Saivercon */
            esc_html__('Você está utilizando a versão grátis do plugin. Para mais funcionalidades, visite %s.', 'telecom-opcoes-e-planos'),
            '<a href="' . esc_url('https://www.saivercon.com/telecom-opcoes-e-planos') . '" target="_blank">' . esc_html__('nosso site', 'telecom-opcoes-e-planos') . '</a>'
        );
        echo '</p></div>';
    }
}